@@ -162,7 +162,13 @@ enum PixelFormat {
 	// (ie., first all Y', then all Cb, then all Cr). bmusb doesn't
 	// produce this, nor does it specify a mechanism to describe
 	// the precise details of the format.
-	PixelFormat_8BitYCbCrPlanar
+	PixelFormat_8BitYCbCrPlanar,
+
+	// These exist only so that the type is guaranteed wide enough
+	// to contain values up to 127. CaptureInterface instances
+	// are free to use them as they see fit for private uses.
+	PixelFormat_Unused100 = 100,
+	PixelFormat_Unused127 = 127
 };
 
 typedef std::function<void(uint16_t timecode,
